@@ -1,18 +1,17 @@
 """Top-level package for stLearn."""
 
 __author__ = """Genomics and Machine Learning lab"""
-__email__ = 'duy.pham@uq.edu.au'
-__version__ = '0.3.0'
+__email__ = "duy.pham@uq.edu.au"
+__version__ = "0.3.1"
 
 
-from . import read
 from . import add
 from . import pp
 from . import em
 from . import tl
 from . import pl
-from . import view
 from . import spatial
+from . import datasets
 
 # Wrapper
 
@@ -21,5 +20,6 @@ from .wrapper.read import Read10X
 from .wrapper.read import ReadOldST
 from .wrapper.read import ReadMERFISH
 from .wrapper.read import ReadSeqFish
-from .wrapper.clustering import SMEclust
+from .wrapper.read import create_stlearn
 from ._settings import settings
+from .wrapper.convert_scanpy import convert_scanpy
