@@ -6,5 +6,5 @@
 from stlearn.gui import main
 
 
-if __name__ == '__main__':  # pragma: no cover
+if __name__ == "__main__":  # pragma: no cover
     main()
