@@ -1,11 +1,13 @@
 from .plotting.gene_plot import gene_plot
+from .plotting.gene_plot import gene_plot_interactive
 from .plotting.cluster_plot import cluster_plot
+from .plotting.cluster_plot import cluster_plot_interactive
 from .plotting.subcluster_plot import subcluster_plot
-from .plotting.microenv_plot import microenv_plot
 from .plotting.non_spatial_plot import non_spatial_plot
 from .plotting.deconvolution_plot import deconvolution_plot
 from .plotting import trajectory
 from .plotting.QC_plot import QC_plot
 from .plotting.cci_plot import het_plot
+from .plotting.cci_plot import het_plot_interactive
 from .plotting.cci_plot import grid_plot
-from .plotting.mask_plot import plot_mask
\ No newline at end of file
+from .plotting.mask_plot import plot_mask
