@@ -4,12 +4,13 @@ import numpy as np
 import pandas as pd
 import networkx as nx
 from scipy.spatial.distance import cdist
+from ...utils import _read_graph
 
 
 def global_level(
     adata: AnnData,
     use_label: str = "louvain",
-    list_cluster: list = [],
+    list_clusters: list = [],
     return_graph: bool = False,
     w: float = None,
     verbose: bool = True,
@@ -23,7 +24,7 @@ def global_level(
     ----------
     adata
         Annotated data matrix.
-    list_cluster
+    list_clusters
         Setup a list of cluster to perform pseudo-space-time
     use_label
         Use label result of clustering method.
@@ -40,12 +41,12 @@ def global_level(
 
     assert w <= 1, "w should be in range 0 to 1"
     # Get global graph
-    G = adata.uns["global_graph"]
+    G = _read_graph(adata, "global_graph")
     # Convert to directed graph
     H = G.to_directed()
 
     # Query cluster
-    query_nodes = list_cluster
+    query_nodes = list_clusters
     query_nodes = ordering_nodes(query_nodes, use_label, adata)
 
     if verbose:
@@ -94,6 +95,7 @@ def global_level(
 
     # Get centroid dictionary
     centroid_dict = adata.uns["centroid_dict"]
+    centroid_dict = {int(key): centroid_dict[key] for key in centroid_dict}
 
     H_sub = H.edge_subgraph(edge_list)
     H_sub = nx.DiGraph(H_sub)
@@ -107,7 +109,7 @@ def global_level(
         sum(prepare_root[:, 0]) / len(prepare_root[:, 0]),
         sum(prepare_root[:, 1]) / len(prepare_root[:, 1]),
     )
-    centroid_dict[9999] = centroide
+    centroid_dict[9999] = np.array(centroide)
 
     labels = nx.get_edge_attributes(H_sub, "weight")
 
@@ -126,7 +128,15 @@ def global_level(
     # H_sub.remove_edges_from(remove)
     # remove.remove_node(9999)
 
-    adata.uns["PTS_graph"] = H_sub
+    H_nodes = list(range(len(H_sub.nodes)))
+
+    node_convert = {}
+    for pair in zip(list(H_sub.nodes), H_nodes):
+        node_convert[pair[1]] = pair[0]
+
+    adata.uns["PTS_graph"] = {}
+    adata.uns["PTS_graph"]["graph"] = nx.to_scipy_sparse_matrix(H_sub)
+    adata.uns["PTS_graph"]["node_dict"] = node_convert
 
     if return_graph:
         return H_sub
@@ -198,6 +208,7 @@ def spatial_distance_matrix(adata, cluster1, cluster2, use_label):
     chosen_adata2 = adata[list(tmp.index)]
 
     centroid_dict = adata.uns["centroid_dict"]
+    centroid_dict = {int(key): centroid_dict[key] for key in centroid_dict}
 
     sub_coord1 = []
     chosen_sub1 = chosen_adata1.obs["sub_cluster_labels"].unique()
