@@ -12,6 +12,8 @@ import scanpy
 import scipy
 
 _QUALITY = Literal["fulres", "hires", "lowres"]
+_background = ["black", "white"]
+
 
 def Read10X(
     path: Union[str, Path],
@@ -77,26 +79,29 @@ def Read10X(
 
     from scanpy import read_visium
 
-    adata = read_visium(path, genome=genome,
-                        count_file=count_file,
-                        library_id=library_id,
-                        load_images=load_images)
+    adata = read_visium(
+        path,
+        genome=genome,
+        count_file=count_file,
+        library_id=library_id,
+        load_images=load_images,
+    )
     adata.var_names_make_unique()
 
-    adata.obs['sum_counts'] = np.array(adata.X.sum(axis=1))
-
     if library_id is None:
         library_id = list(adata.uns["spatial"].keys())[0]
 
     if quality == "fulres":
         image_coor = adata.obsm["spatial"]
     else:
-        scale = adata.uns["spatial"][library_id]["scalefactors"]["tissue_" + quality + "_scalef"]
+        scale = adata.uns["spatial"][library_id]["scalefactors"][
+            "tissue_" + quality + "_scalef"
+        ]
         image_coor = adata.obsm["spatial"] * scale
 
     adata.obs["imagecol"] = image_coor[:, 0]
     adata.obs["imagerow"] = image_coor[:, 1]
-    adata.uns["spatial"]["use_quality"] = quality
+    adata.uns["spatial"][library_id]["use_quality"] = quality
 
     return adata
 
@@ -108,6 +113,7 @@ def ReadOldST(
     library_id: str = "OldST",
     scale: float = 1.0,
     quality: str = "hires",
+    spot_diameter_fullres: float = 50,
 ) -> AnnData:
 
     """\
@@ -127,19 +133,25 @@ def ReadOldST(
         Set scale factor.
     quality
         Set quality that convert to stlearn to use. Store in anndata.obs['imagecol' & 'imagerow']
+    spot_diameter_fullres
+        Diameter of spot in full resolution
+
     Returns
     -------
     AnnData
     """
 
-    adata = stlearn.read.file_table(count_matrix_file)
+    adata = scanpy.read_text(count_matrix_file)
     adata = stlearn.add.parsing(adata, coordinates_file=spatial_file)
     stlearn.add.image(
-        adata, library_id=library_id, quality=quality, imgpath=image_file, scale=scale
+        adata,
+        library_id=library_id,
+        quality=quality,
+        imgpath=image_file,
+        scale=scale,
+        spot_diameter_fullres=spot_diameter_fullres,
     )
 
-    adata.obs["sum_counts"] = np.array(adata.X.sum(axis=1))
-
     return adata
 
 
@@ -149,6 +161,8 @@ def ReadSlideSeq(
     library_id: str = None,
     scale: float = 1.0,
     quality: str = "hires",
+    spot_diameter_fullres: float = 50,
+    background_color: _background = "white",
 ) -> AnnData:
 
     """\
@@ -166,6 +180,11 @@ def ReadSlideSeq(
         Set scale factor.
     quality
         Set quality that convert to stlearn to use. Store in anndata.obs['imagecol' & 'imagerow']
+    spot_diameter_fullres
+        Diameter of spot in full resolution
+    background_color
+        Color of the backgound. Only `black` or `white` is allowed.
+
     Returns
     -------
     AnnData
@@ -187,7 +206,10 @@ def ReadSlideSeq(
     max_size = np.max([adata.obs["imagecol"].max(), adata.obs["imagerow"].max()])
     max_size = int(max_size + 0.1 * max_size)
 
-    image = Image.new("RGB", (max_size, max_size), (0, 0, 0))
+    if background_color == "black":
+        image = Image.new("RGB", (max_size, max_size), (0, 0, 0))
+    else:
+        image = Image.new("RGB", (max_size, max_size), (255, 255, 255))
     imgarr = np.array(image)
 
     if library_id is None:
@@ -197,14 +219,16 @@ def ReadSlideSeq(
     adata.uns["spatial"][library_id] = {}
     adata.uns["spatial"][library_id]["images"] = {}
     adata.uns["spatial"][library_id]["images"][quality] = imgarr
-    adata.uns["spatial"]["use_quality"] = quality
+    adata.uns["spatial"][library_id]["use_quality"] = quality
     adata.uns["spatial"][library_id]["scalefactors"] = {}
     adata.uns["spatial"][library_id]["scalefactors"][
         "tissue_" + quality + "_scalef"
     ] = scale
-    adata.obsm["spatial"] = meta[["x", "y"]].values
 
-    adata.obs["sum_counts"] = np.array(adata.X.sum(axis=1))
+    adata.uns["spatial"][library_id]["scalefactors"][
+        "spot_diameter_fullres"
+    ] = spot_diameter_fullres
+    adata.obsm["spatial"] = adata.obs[["imagecol", "imagerow"]].values
 
     return adata
 
@@ -215,6 +239,8 @@ def ReadMERFISH(
     library_id: str = None,
     scale: float = 1,
     quality: str = "hires",
+    spot_diameter_fullres: float = 50,
+    background_color: _background = "white",
 ) -> AnnData:
 
     """\
@@ -232,6 +258,11 @@ def ReadMERFISH(
         Set scale factor.
     quality
         Set quality that convert to stlearn to use. Store in anndata.obs['imagecol' & 'imagerow']
+    spot_diameter_fullres
+        Diameter of spot in full resolution
+    background_color
+        Color of the backgound. Only `black` or `white` is allowed.
+
     Returns
     -------
     AnnData
@@ -246,15 +277,18 @@ def ReadMERFISH(
 
     adata_merfish = counts[coordinates.index, :]
     adata_merfish.obsm["spatial"] = coordinates.to_numpy()
-    adata_merfish.obs["imagecol"] = adata_merfish.obsm["spatial"][:, 0]
-    adata_merfish.obs["imagerow"] = adata_merfish.obsm["spatial"][:, 1]
+    adata_merfish.obs["imagecol"] = adata_merfish.obsm["spatial"][:, 0] * scale
+    adata_merfish.obs["imagerow"] = adata_merfish.obsm["spatial"][:, 1] * scale
 
     # Create image
     max_size = np.max(
         [adata_merfish.obs["imagecol"].max(), adata_merfish.obs["imagerow"].max()]
     )
     max_size = int(max_size + 0.1 * max_size)
-    image = Image.new("RGB", (max_size, max_size), (255, 255, 255))
+    if background_color == "black":
+        image = Image.new("RGB", (max_size, max_size), (0, 0, 0))
+    else:
+        image = Image.new("RGB", (max_size, max_size), (255, 255, 255))
     imgarr = np.array(image)
 
     if library_id is None:
@@ -264,16 +298,14 @@ def ReadMERFISH(
     adata_merfish.uns["spatial"][library_id] = {}
     adata_merfish.uns["spatial"][library_id]["images"] = {}
     adata_merfish.uns["spatial"][library_id]["images"][quality] = imgarr
-    adata_merfish.uns["spatial"]["use_quality"] = quality
+    adata_merfish.uns["spatial"][library_id]["use_quality"] = quality
     adata_merfish.uns["spatial"][library_id]["scalefactors"] = {}
     adata_merfish.uns["spatial"][library_id]["scalefactors"][
         "tissue_" + quality + "_scalef"
     ] = scale
-
-    adata_merfish.obs["imagecol"] = adata_merfish.obsm["spatial"][:, 0] * scale
-    adata_merfish.obs["imagerow"] = adata_merfish.obsm["spatial"][:, 1] * scale
-
-    adata_merfish.obs["sum_counts"] = np.array(adata_merfish.X.sum(axis=1))
+    adata_merfish.uns["spatial"][library_id]["scalefactors"][
+        "spot_diameter_fullres"
+    ] = spot_diameter_fullres
 
     return adata_merfish
 
@@ -285,6 +317,8 @@ def ReadSeqFish(
     scale: float = 1.0,
     quality: str = "hires",
     field: int = 0,
+    spot_diameter_fullres: float = 50,
+    background_color: _background = "white",
 ) -> AnnData:
 
     """\
@@ -304,6 +338,10 @@ def ReadSeqFish(
         Set quality that convert to stlearn to use. Store in anndata.obs['imagecol' & 'imagerow']
     field
         Set field of view for SeqFish data
+    spot_diameter_fullres
+        Diameter of spot in full resolution
+    background_color
+        Color of the backgound. Only `black` or `white` is allowed.
     Returns
     -------
     AnnData
@@ -328,7 +366,10 @@ def ReadSeqFish(
     max_size = np.max([adata.obs["imagecol"].max(), adata.obs["imagerow"].max()])
     max_size = int(max_size + 0.1 * max_size)
 
-    image = Image.new("RGB", (max_size, max_size), (255, 255, 255))
+    if background_color == "black":
+        image = Image.new("RGB", (max_size, max_size), (0, 0, 0))
+    else:
+        image = Image.new("RGB", (max_size, max_size), (255, 255, 255))
     imgarr = np.array(image)
 
     if library_id is None:
@@ -338,13 +379,89 @@ def ReadSeqFish(
     adata.uns["spatial"][library_id] = {}
     adata.uns["spatial"][library_id]["images"] = {}
     adata.uns["spatial"][library_id]["images"][quality] = imgarr
-    adata.uns["spatial"]["use_quality"] = quality
+    adata.uns["spatial"][library_id]["use_quality"] = quality
     adata.uns["spatial"][library_id]["scalefactors"] = {}
     adata.uns["spatial"][library_id]["scalefactors"][
         "tissue_" + quality + "_scalef"
     ] = scale
-    adata.obsm["spatial"] = spatial[["X", "Y"]].values
+    adata.uns["spatial"][library_id]["scalefactors"][
+        "spot_diameter_fullres"
+    ] = spot_diameter_fullres
+    adata.obsm["spatial"] = adata.obs[["imagecol", "imagerow"]].values
 
-    adata.obs["sum_counts"] = np.array(adata.X.sum(axis=1))
+    return adata
+
+
+def create_stlearn(
+    count: pd.DataFrame,
+    spatial: pd.DataFrame,
+    library_id: str,
+    image_path: Optional[Path] = None,
+    scale: float = 1.0,
+    quality: str = "hires",
+    spot_diameter_fullres: float = 50,
+    background_color: _background = "white",
+):
+    """\
+    Create AnnData object for stLearn
+
+    Parameters
+    ----------
+    count
+        Pandas Dataframe of count matrix with rows as barcodes and columns as gene names
+    spatial
+        Pandas Dataframe of spatial location of cells/spots.
+    library_id
+        Identifier for the visium library. Can be modified when concatenating multiple adata objects.
+    scale
+        Set scale factor.
+    quality
+        Set quality that convert to stlearn to use. Store in anndata.obs['imagecol' & 'imagerow']
+    spot_diameter_fullres
+        Diameter of spot in full resolution
+    background_color
+        Color of the backgound. Only `black` or `white` is allowed.
+    Returns
+    -------
+    AnnData
+    """
+    adata = AnnData(X=count)
+
+    adata.obsm["spatial"] = spatial.values
+    adata.obs["imagecol"] = spatial["imagecol"].values * scale
+    adata.obs["imagerow"] = spatial["imagerow"].values * scale
+
+    if image_path != None:
+        stlearn.add.image(
+            adata,
+            library_id=library_id,
+            quality=quality,
+            imgpath=image_path,
+            scale=scale,
+        )
+    else:
+        # Create image
+        max_size = np.max([adata.obs["imagecol"].max(), adata.obs["imagerow"].max()])
+        max_size = int(max_size + 0.1 * max_size)
+
+        if background_color == "black":
+            image = Image.new("RGB", (max_size, max_size), (0, 0, 0))
+        else:
+            image = Image.new("RGB", (max_size, max_size), (255, 255, 255))
+        imgarr = np.array(image)
+
+        # Create spatial dictionary
+        adata.uns["spatial"] = {}
+        adata.uns["spatial"][library_id] = {}
+        adata.uns["spatial"][library_id]["images"] = {}
+        adata.uns["spatial"][library_id]["images"][quality] = imgarr
+        adata.uns["spatial"][library_id]["use_quality"] = quality
+        adata.uns["spatial"][library_id]["scalefactors"] = {}
+        adata.uns["spatial"][library_id]["scalefactors"][
+            "tissue_" + quality + "_scalef"
+        ] = scale
+        adata.uns["spatial"][library_id]["scalefactors"][
+            "spot_diameter_fullres"
+        ] = spot_diameter_fullres
 
     return adata
